.. raw:: html

    <p>
      <h1>
        Queensbarry - qb
      </h1>
    </p>

.. image:: https://img.shields.io/pypi/v/queensbarry
    :target: https://pypi.org/project/queensbarry/


Queensbarry Tools Collection
----

- geo
- statistics
    - error analysis
- pako: use for decode and encode object

